@@ -131,6 +131,65 @@ namespace Tomboy
 				dialog.Destroy ();
 			}
 		}
+		
+		/// <summary>
+		/// Get a string that is more friendly/pretty for the specified date.
+		/// For example, "Today, 3:00 PM", "4 days ago, 9:20 AM".
+		/// <param name="date">The DateTime to evaluate</param>
+		/// <param name="show_time">If true, output the time along with the
+		/// date</param>
+		/// </summary>
+		public static string GetPrettyPrintDate (DateTime date, bool show_time)
+		{
+			string pretty_str = String.Empty;
+			DateTime now = DateTime.Now;
+			string short_time = date.ToShortTimeString ();
+
+			if (date.Year == now.Year) {
+				if (date.DayOfYear == now.DayOfYear)
+					pretty_str = show_time ?
+						String.Format (Catalog.GetString ("Today, {0}"), 
+							      short_time) :
+						Catalog.GetString ("Today");
+				else if (date.DayOfYear < now.DayOfYear
+							&& date.DayOfYear == now.DayOfYear - 1)
+					pretty_str = show_time ?
+						String.Format (Catalog.GetString ("Yesterday, {0}"),
+									short_time) :
+						Catalog.GetString ("Yesterday");
+				else if (date.DayOfYear < now.DayOfYear
+							&& date.DayOfYear > now.DayOfYear - 6)
+					pretty_str = show_time ?
+						String.Format (Catalog.GetString ("{0} days ago, {1}"),
+							now.DayOfYear - date.DayOfYear, short_time) :
+						String.Format (Catalog.GetString ("{0} days ago"),
+							now.DayOfYear - date.DayOfYear);
+				else if (date.DayOfYear > now.DayOfYear
+							&& date.DayOfYear == now.DayOfYear + 1)
+					pretty_str = show_time ?
+						String.Format (Catalog.GetString ("Tomorrow, {0}"),
+									short_time) :
+						Catalog.GetString ("Tomorrow");
+				else if (date.DayOfYear > now.DayOfYear
+							&& date.DayOfYear < now.DayOfYear + 6)
+					pretty_str = show_time ?
+						String.Format (Catalog.GetString ("In {0} days, {1}"),
+							date.DayOfYear - now.DayOfYear, short_time) :
+						String.Format (Catalog.GetString ("In {0} days"),
+							date.DayOfYear - now.DayOfYear);
+				else
+					pretty_str = show_time ?
+						date.ToString (Catalog.GetString ("MMMM d, h:mm tt")) :
+						date.ToString (Catalog.GetString ("MMMM d"));
+			} else if (date == DateTime.MinValue)
+				pretty_str = Catalog.GetString ("No Date");
+			else
+				pretty_str = show_time ?
+					date.ToString (Catalog.GetString ("MMMM d yyyy, h:mm tt")) :
+					date.ToString (Catalog.GetString ("MMMM d yyyy"));
+				
+			return pretty_str;
+		}
 	}
 
 	public class GlobalKeybinder 
@@ -798,6 +857,10 @@ namespace Tomboy
 			action_manager.LoadInterface ();
 
 			RegisterSignalHandlers ();
+			
+			// Register handler for saving session when logging out of Gnome
+			Gnome.Client client = Gnome.Global.MasterClient ();
+			client.SaveYourself += OnSaveYourself;
 		}
 
 		[DllImport("libc")]
@@ -828,6 +891,14 @@ namespace Tomboy
 			Stdlib.signal (Signum.SIGINT, OnExitSignal);
 		}
 
+		static void OnSaveYourself (object sender, Gnome.SaveYourselfArgs args)
+		{
+			Logger.Log ("Received request for saving session");
+			
+			if (ExitingEvent != null)
+				ExitingEvent (null, new EventArgs ());
+		}
+
 		public static void RegisterSessionManagerRestart (string executable_path,
 								  string[] args, 
 								  string[] environment)
